@@ -12,9 +12,7 @@ from pkg_resources import resource_filename
 from bs4 import BeautifulSoup
 import pyvo
 
-
-from six.moves.urllib_parse import urljoin
-import six
+from urllib.parse import urljoin
 from astropy.table import Table, Column, vstack
 from astroquery import log
 from astropy.utils import deprecated
@@ -545,18 +543,19 @@ class AlmaClass(QueryWithLogin):
 
         """
         Return information about the data associated with ALMA uid(s)
+
         Parameters
         ----------
-        uids: list or str
+        uids : list or str
             A list of valid UIDs or a single UID.
             UIDs should have the form: 'uid://A002/X391d0b/X7b'
-        expand_tarfiles: bool
+        expand_tarfiles : bool
             False to return information on the tarfiles packages containing
             the data or True to return information about individual files in
             these packages
-        with_auxiliary: bool
+        with_auxiliary : bool
             True to include the auxiliary packages, False otherwise
-        with_rawdata: bool
+        with_rawdata : bool
             True to include raw data, False otherwise
 
         Returns
@@ -567,7 +566,7 @@ class AlmaClass(QueryWithLogin):
         """
         if uids is None:
             raise AttributeError('UIDs required')
-        if isinstance(uids, six.string_types + (np.bytes_,)):
+        if isinstance(uids, (str, bytes)):
             uids = [uids]
         if not isinstance(uids, (list, tuple, np.ndarray)):
             raise TypeError("Datasets must be given as a list of strings.")
@@ -578,7 +577,7 @@ class AlmaClass(QueryWithLogin):
             if res.status[0] != 'OK':
                 raise Exception('ERROR {}: {}'.format(res.status[0],
                                                       res.status[1]))
-            temp = res.table
+            temp = res.to_table()
             if ASTROPY_LT_4_1:
                 # very annoying
                 for col in [x for x in temp.colnames
@@ -647,9 +646,11 @@ class AlmaClass(QueryWithLogin):
         query = "select distinct data_rights from ivoa.obscore where " \
                 "obs_id='{}'".format(uid)
         result = self.query_tap(query)
-        if not result or len(result.table) == 0:
+        if result:
+            tableresult = result.to_table()
+        if not result or len(tableresult) == 0:
             raise AttributeError('{} not found'.format(uid))
-        if len(result.table) == 1 and result.table[0][0] == 'Public':
+        if len(tableresult) == 1 and tableresult[0][0] == 'Public':
             return False
         return True
 
@@ -811,7 +812,7 @@ class AlmaClass(QueryWithLogin):
         downloaded_files : list
             A list of the downloaded file paths
         """
-        if isinstance(uids, six.string_types + (np.bytes_,)):
+        if isinstance(uids, (str, bytes)):
             uids = [uids]
         if not isinstance(uids, (list, tuple, np.ndarray)):
             raise TypeError("Datasets must be given as a list of strings.")
@@ -1073,7 +1074,7 @@ class AlmaClass(QueryWithLogin):
             data from an ASDM tarball
         """
 
-        if isinstance(urls, six.string_types):
+        if isinstance(urls, str):
             urls = [urls]
         if not isinstance(urls, (list, tuple, np.ndarray)):
             raise TypeError("Datasets must be given as a list of strings.")
@@ -1174,7 +1175,6 @@ class AlmaClass(QueryWithLogin):
         March 2020 - should be removed along with stage_data_prefeb2020
         """
         from ..utils import url_helpers
-        from six import iteritems
         columns = {'mous_uid': [], 'URL': [], 'size': []}
         for entry in data['node_data']:
             # de_type can be useful (e.g., MOUS), but it is not necessarily
@@ -1212,7 +1212,7 @@ class AlmaClass(QueryWithLogin):
 
         columns['size'] = u.Quantity(columns['size'], u.Gbyte)
 
-        tbl = Table([Column(name=k, data=v) for k, v in iteritems(columns)])
+        tbl = Table([Column(name=k, data=v) for k, v in columns.items()])
         return tbl
 
     def get_project_metadata(self, projectid, cache=True):
