@@ -1,20 +1,19 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import print_function
+
 import time
 import sys
 import os.path
 import shutil
 import webbrowser
-import getpass
 import warnings
 import keyring
 import numpy as np
+import re
 from bs4 import BeautifulSoup
 
-from astropy.extern.six import BytesIO
-from astropy.extern import six
+from io import BytesIO
 from astropy.table import Table, Column
-from astropy import log
+from astroquery import log
 
 from ..exceptions import LoginError, RemoteServiceError, NoResultsWarning
 from ..utils import schema, system_tools
@@ -47,6 +46,7 @@ class EsoClass(QueryWithLogin):
         super(EsoClass, self).__init__()
         self._instrument_list = None
         self._survey_list = None
+        self.username = None
 
     def _activate_form(self, response, form_index=0, form_id=None, inputs={},
                        cache=True, method=None):
@@ -209,27 +209,21 @@ class EsoClass(QueryWithLogin):
             on the keyring. Default is False.
         """
         if username is None:
-            if self.USERNAME == "":
+            if self.USERNAME != "":
+                username = self.USERNAME
+            elif self.username is not None:
+                username = self.username
+            else:
                 raise LoginError("If you do not pass a username to login(), "
                                  "you should configure a default one!")
-            else:
-                username = self.USERNAME
+        else:
+            # store username as we may need it to re-authenticate
+            self.username = username
 
         # Get password from keyring or prompt
-        if reenter_password is False:
-            password_from_keyring = keyring.get_password(
-                "astroquery:www.eso.org", username)
-        else:
-            password_from_keyring = None
+        password, password_from_keyring = self._get_password(
+            "astroquery:www.eso.org", username, reenter=reenter_password)
 
-        if password_from_keyring is None:
-            if system_tools.in_ipynb():
-                log.warning("You may be using an ipython notebook:"
-                            " the password form will appear in your terminal.")
-            password = getpass.getpass("{0}, enter your ESO password:\n"
-                                       .format(username))
-        else:
-            password = password_from_keyring
         # Authenticate
         log.info("Authenticating {0} on www.eso.org...".format(username))
 
@@ -352,7 +346,7 @@ class EsoClass(QueryWithLogin):
             survey_form = self._request("GET", url, cache=cache)
             query_dict = kwargs
             query_dict["wdbo"] = "csv/download"
-            if isinstance(surveys, six.string_types):
+            if isinstance(surveys, str):
                 surveys = surveys.split(",")
             query_dict['collection_name'] = surveys
             if self.ROW_LIMIT >= 0:
@@ -515,7 +509,7 @@ class EsoClass(QueryWithLogin):
 
         """
         _schema_product_ids = schema.Schema(
-            schema.Or(Column, [schema.Or(*six.string_types)]))
+            schema.Or(Column, [schema.Schema(str)]))
         _schema_product_ids.validate(product_ids)
         # Get all headers
         result = []
@@ -563,47 +557,21 @@ class EsoClass(QueryWithLogin):
         # Return as Table
         return Table(result)
 
-    def retrieve_data(self, datasets, continuation=False, destination=None):
-        """
-        Retrieve a list of datasets form the ESO archive.
+    def _check_existing_files(self, datasets, continuation=False,
+                              destination=None):
+        """Detect already downloaded datasets."""
 
-        Parameters
-        ----------
-        datasets : list of strings or string
-            List of datasets strings to retrieve from the archive.
-        destination: string
-            Directory where the files are copied.
-            Files already found in the destination directory are skipped.
-            Default to astropy cache.
-
-        Returns
-        -------
-        files : list of strings or string
-            List of files that have been locally downloaded from the archive.
-
-        Examples
-        --------
-        >>> dptbl = Eso.query_instrument('apex', pi_coi='ginsburg')
-        >>> dpids = [row['DP.ID'] for row in dptbl if 'Map' in row['Object']]
-        >>> files = Eso.retrieve_data(dpids)
-
-        """
         datasets_to_download = []
         files = []
 
-        if isinstance(datasets, six.string_types):
-            return_list = False
-            datasets = [datasets]
-        else:
-            return_list = True
-        if not isinstance(datasets, (list, tuple, np.ndarray)):
-            raise TypeError("Datasets must be given as a list of strings.")
-
-        # First: Detect datasets already downloaded
-        log.info("Detecting already downloaded datasets...")
         for dataset in datasets:
-            if os.path.splitext(dataset)[1].lower() in ('.fits', '.tar'):
+            ext = os.path.splitext(dataset)[1].lower()
+            if ext in ('.fits', '.tar'):
                 local_filename = dataset
+            elif ext == '.fz':
+                local_filename = dataset[:-3]
+            elif ext == '.z':
+                local_filename = dataset[:-2]
             else:
                 local_filename = dataset + ".fits"
 
@@ -634,6 +602,97 @@ class EsoClass(QueryWithLogin):
             else:
                 datasets_to_download.append(dataset)
 
+        return datasets_to_download, files
+
+    def _download_file(self, url, local_filepath, **kwargs):
+        """ Wraps QueryWithLogin._download_file to detect if the
+        authentication expired.
+        """
+        trials = 1
+        while trials <= 2:
+            resp = super(EsoClass, self)._download_file(url, local_filepath,
+                                                        **kwargs)
+
+            # trying to detect the failing authentication:
+            # - content type should not be html
+            if (resp.headers['Content-Type'] == 'text/html;charset=UTF-8' and
+                    resp.url.startswith('https://www.eso.org/sso/login')):
+                if trials == 1:
+                    log.warning("Session expired, trying to re-authenticate")
+                    self.login()
+                    trials += 1
+                else:
+                    raise LoginError("Could not authenticate")
+            else:
+                break
+
+        return resp
+
+    def retrieve_data(self, datasets, continuation=False, destination=None,
+                      with_calib='none', request_all_objects=False, unzip=True):
+        """
+        Retrieve a list of datasets form the ESO archive.
+
+        Parameters
+        ----------
+        datasets : list of strings or string
+            List of datasets strings to retrieve from the archive.
+        destination: string
+            Directory where the files are copied.
+            Files already found in the destination directory are skipped,
+            unless continuation=True.
+            Default to astropy cache.
+        continuation : bool
+            Force the retrieval of data that are present in the destination
+            directory.
+        with_calib : string
+            Retrieve associated calibration files: 'none' (default), 'raw' for
+            raw calibrations, or 'processed' for processed calibrations.
+        request_all_objects : bool
+            When retrieving associated calibrations (``with_calib != 'none'``),
+            this allows to request all the objects included the already
+            downloaded ones, to be sure to retrieve all calibration files.
+            This is useful when the download was interrupted. `False` by
+            default.
+        unzip : bool
+            Unzip compressed files from the archive after download. `True` by
+            default.
+
+        Returns
+        -------
+        files : list of strings or string
+            List of files that have been locally downloaded from the archive.
+
+        Examples
+        --------
+        >>> dptbl = Eso.query_instrument('apex', pi_coi='ginsburg')
+        >>> dpids = [row['DP.ID'] for row in dptbl if 'Map' in row['Object']]
+        >>> files = Eso.retrieve_data(dpids)
+
+        """
+        calib_options = {'none': '', 'raw': 'CalSelectorRaw2Raw',
+                         'processed': 'CalSelectorRaw2Master'}
+
+        if with_calib not in calib_options:
+            raise ValueError("invalid value for 'with_calib', "
+                             "it must be 'none', 'raw' or 'processed'")
+
+        if isinstance(datasets, str):
+            return_list = False
+            datasets = [datasets]
+        else:
+            return_list = True
+        if not isinstance(datasets, (list, tuple, np.ndarray)):
+            raise TypeError("Datasets must be given as a list of strings.")
+
+        # First: Detect datasets already downloaded
+        if with_calib != 'none' and request_all_objects:
+            datasets_to_download, files = list(datasets), []
+        else:
+            log.info("Detecting already downloaded datasets...")
+            datasets_to_download, files = self._check_existing_files(
+                datasets, continuation=continuation, destination=destination)
+
         # Second: Check that the datasets to download are in the archive
         log.info("Checking availability of datasets to download...")
         valid_datasets = [self.verify_data_exists(ds)
@@ -668,14 +727,17 @@ class EsoClass(QueryWithLogin):
                 if login_button:
                     raise LoginError("Not logged in. "
                                      "You must be logged in to download data.")
+                inputs = {}
+                if with_calib != 'none':
+                    inputs['requestCommand'] = calib_options[with_calib]
 
                 # TODO: There may be another screen for Not Authorized; that
                 # should be included too
                 # form name is "retrieve"; no id
                 data_download_form = self._activate_form(
-                    data_confirmation_form, form_index=-1,
+                    data_confirmation_form, form_index=-1, inputs=inputs,
                     cache=False)
-                log.info("Staging form is at {0}."
+                log.info("Staging form is at {0}"
                          .format(data_download_form.url))
                 root = BeautifulSoup(data_download_form.content, 'html5lib')
                 state = root.select('span[id=requestState]')[0].text
@@ -695,17 +757,74 @@ class EsoClass(QueryWithLogin):
                     raise RemoteServiceError("There was a remote service "
                                              "error; perhaps the requested "
                                              "file could not be found?")
-            for fileId in root.select('input[name=fileId]'):
-                log.info("Downloading file {0}...".format(fileId.attrs['value'].split()[0]))
-                fileLink = ("http://dataportal.eso.org/dataPortal" +
-                            fileId.attrs['value'].split()[1])
+
+            if with_calib != 'none':
+                # when requested files with calibrations, some javascript is
+                # used to display the files, which prevent retrieving the files
+                # directly. So instead we retrieve the download script provided
+                # in the web page, and use it to extract the list of files.
+                # The benefit of this is also that in the download script the
+                # list of files is de-duplicated, whereas on the web page the
+                # calibration files would be duplicated for each exposure.
+                link = root.select('a[href$="/script"]')[0]
+                if 'downloadRequest' not in link.text:
+                    # Make sure that we found the correct link
+                    raise RemoteServiceError(
+                        "A link was found in the download file for the "
+                        "calibrations that is not a downloadRequest link "
+                        "and therefore appears invalid.")
+
+                href = link.attrs['href']
+                script = self._request("GET", href, cache=False)
+                fileLinks = re.findall(
+                    r'"(https://dataportal.eso.org/dataPortal/api/requests/.*)"',
+                    script.text)
+
+                # urls with api/ require using Basic Authentication, though
+                # it's easier for us to reuse the existing requests session (to
+                # avoid asking agin for a username/password if it is not
+                # stored). So we remove api/ from the urls:
+                fileLinks = [
+                    f.replace('https://dataportal.eso.org/dataPortal/api/requests',
+                              'https://dataportal.eso.org/dataPortal/requests')
+                    for f in fileLinks]
+
+                log.info("Detecting already downloaded datasets, "
+                         "including calibrations...")
+                fileIds = [f.rsplit('/', maxsplit=1)[1] for f in fileLinks]
+                filteredIds, files = self._check_existing_files(
+                    fileIds, continuation=continuation,
+                    destination=destination)
+
+                fileLinks = [f for f, fileId in zip(fileLinks, fileIds)
+                             if fileId in filteredIds]
+            else:
+                fileIds = root.select('input[name=fileId]')
+                fileLinks = ["http://dataportal.eso.org/dataPortal" +
+                             fileId.attrs['value'].split()[1]
+                             for fileId in fileIds]
+
+            nfiles = len(fileLinks)
+            log.info("Downloading {} files...".format(nfiles))
+            log.debug("Files:\n{}".format('\n'.join(fileLinks)))
+            for i, fileLink in enumerate(fileLinks, 1):
+                fileId = fileLink.rsplit('/', maxsplit=1)[1]
+                log.info("Downloading file {}/{}: {}..."
+                         .format(i, nfiles, fileId))
                 filename = self._request("GET", fileLink, save=True,
                                          continuation=True)
-                log.info("Unzipping file {0}...".format(fileId.attrs['value'].split()[0]))
-                filename = system_tools.gunzip(filename)
+
+                if filename.endswith(('.gz', '.7z', '.bz2', '.xz', '.Z')) and unzip:
+                    log.info("Unzipping file {0}...".format(fileId))
+                    filename = system_tools.gunzip(filename)
+
                 if destination is not None:
-                    log.info("Copying file {0} to {1}...".format(fileId.attrs['value'].split()[0], destination))
-                    shutil.move(filename, os.path.join(destination, os.path.split(filename)[1]))
+                    log.info("Copying file {0} to {1}...".format(fileId, destination))
+                    destfile = os.path.join(destination, os.path.basename(filename))
+                    shutil.move(filename, destfile)
+                    files.append(destfile)
+                else:
+                    files.append(filename)
 
         # Empty the redirect cache of this request session
         # Only available and needed for requests versions < 2.17
@@ -770,9 +889,18 @@ class EsoClass(QueryWithLogin):
             if _check_response(content):
                 # First line is always garbage
                 content = content.split(b'\n', 1)[1]
-                table = Table.read(BytesIO(content), format="ascii.csv",
-                                   guess=False,  # header_start=1,
-                                   comment="#", encoding='utf-8')
+                try:
+                    table = Table.read(BytesIO(content), format="ascii.csv",
+                                       guess=False,  # header_start=1,
+                                       comment="#", encoding='utf-8')
+                except ValueError as ex:
+                    if 'the encoding parameter is not supported on Python 2' in str(ex):
+                        # astropy python2 does not accept the encoding parameter
+                        table = Table.read(BytesIO(content), format="ascii.csv",
+                                           guess=False,
+                                           comment="#")
+                    else:
+                        raise ex
             else:
                 raise RemoteServiceError("Query returned no results")
 
