@@ -1,18 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import numpy as np
+from numpy.testing import assert_allclose
 import pytest
 
 from astropy import coordinates
 from astropy.table import Table
-from astropy.tests.helper import remote_data
 
-from six.moves.urllib_error import URLError
+from urllib.error import URLError
 
 from ... import sdss
 from ...exceptions import TimeoutError
 
 
-@remote_data
+@pytest.mark.remote_data
 class TestSDSSRemote:
     # Test Case: A Seyfert 1 galaxy
     coords = coordinates.SkyCoord('0h8m05.63s +14d50m23.3s')
@@ -99,7 +99,13 @@ class TestSDSSRemote:
         xid = sdss.SDSS.query_specobj(plate=2340)
         assert isinstance(xid, Table)
         for row in table:
-            assert row in xid
+            i = np.nonzero(xid['specobjid'] == row['specobjid'])[0]
+            assert len(i) == 1
+            for j, c in enumerate(colnames):
+                if dtypes[j] is float:
+                    assert_allclose(xid[i][c], row[c])
+                else:
+                    assert xid[i][c] == row[c]
 
     def test_sdss_photoobj(self):
         colnames = ['ra', 'dec', 'objid', 'run', 'rerun', 'camcol', 'field']
@@ -120,7 +126,13 @@ class TestSDSSRemote:
         xid = sdss.SDSS.query_photoobj(run=1904, camcol=3, field=164)
         assert isinstance(xid, Table)
         for row in table:
-            assert row in xid
+            i = np.nonzero(xid['objid'] == row['objid'])[0]
+            assert len(i) == 1
+            for j, c in enumerate(colnames):
+                if dtypes[j] is float:
+                    assert_allclose(xid[i][c], row[c])
+                else:
+                    assert xid[i][c] == row[c]
 
     @pytest.mark.xfail(reason=("Timeout isn't raised since switching to "
                                "self._request, fix it before merging #586"))
@@ -136,13 +148,13 @@ class TestSDSSRemote:
 
     def test_query_non_default_field(self):
         # A regression test for #469
-        query1 = sdss.SDSS.query_region(self.coords, fields=['r'])
+        query1 = sdss.SDSS.query_region(self.coords, fields=['r', 'psfMag_r'])
 
         query2 = sdss.SDSS.query_region(self.coords, fields=['ra', 'dec', 'r'])
         assert isinstance(query1, Table)
         assert isinstance(query2, Table)
 
-        assert query1.colnames == ['r']
+        assert query1.colnames == ['r', 'psfMag_r']
         assert query2.colnames == ['ra', 'dec', 'r']
 
     def test_query_crossid(self):
